@@ -8,5 +8,5 @@ fragment ProgramInvitation on ProgramInvitation {
 
 
 class ProgramInvitation(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
