@@ -1,5 +1,4 @@
 from ..node import Node
-from gql import gql
 
 programModuleFragment = """
 fragment ProgramModule on ProgramModule {
@@ -11,7 +10,7 @@ fragment ProgramModule on ProgramModule {
 
 
 class ProgramModule(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
 
     @property
